import {
	Body,
	Controller,
	DefaultValuePipe,
	Delete,
	Get,
	Param,
	ParseIntPipe,
	Post,
	Query,
	UseGuards,
} from "@nestjs/common";
import { AdminGuard } from "apps/backend/src/app/auth/auth.guard";
import { CreateGroupDto } from "apps/backend/src/app/groups/groups.dto";
import { ISearchQuery } from "apps/backend/src/app/groups/groups.types";
import { GroupsService } from "./groups.service";

@Controller("groups")
export class GroupsController {
	constructor(private readonly groupsService: GroupsService) {}

	@Get("find")
	async findMany(
		@Query("limit", new DefaultValuePipe(20), ParseIntPipe) limit: number,
		@Query("offset", new DefaultValuePipe(0), ParseIntPipe) offset: number,
		@Query("search", new DefaultValuePipe("")) search: string,
	) {
		return await this.groupsService.getGroupsByName(limit, offset, search);
	}

	@Post("new")
	async newGroup(@Body() body: CreateGroupDto) {
		return await this.groupsService.newGroup(body.groupName);
	}

	@UseGuards(AdminGuard)
	@Delete(":groupId")
	async deleteGroup(@Param("groupId") groupId: string) {
		return await this.groupsService.deleteGroup(groupId);
	}

	//TODO Patch

	@Get("files/:groupId")
	async getFilesForGroup(
		@Query("limit", new DefaultValuePipe(20), ParseIntPipe) limit: number,
		@Query("offset", new DefaultValuePipe(0), ParseIntPipe) offset: number,
		@Query("search", new DefaultValuePipe("")) search: string,
		@Param("groupId") groupId: string,
	) {
		return await this.groupsService.findFilesForGroup(
			limit,
			offset,
			search,
			groupId,
		);
	}
}
