"use client"
import { Dispatch, SetStateAction, useState } from 'react';
import { Button } from '../components/ui/button';
import { Home, NotepadTextDashed } from 'lucide-react';
import { NewFileModal } from 'apps/frontend/src/components/new-file-modal';
import {
  ResizableHandle,
  ResizablePanel,
  ResizablePanelGroup
} from 'apps/frontend/src/components/ui/resizable';

export enum ESubPage {
  Home,
  Documentation,
}

export default function HomePage() {
  const [currentSubPage, setCurrentSubPage] = useState<ESubPage>(0)
  return (
    <main className="w-full h-full bg-background border border-muted p-2 rounded-md flex flex-row justify-stretch items-stretch">
      <ResizablePanelGroup
        direction="horizontal">
        <ResizablePanel
          defaultSize={20}
          minSize={15}
          maxSize={25}
          className={"w-1/5 h-full p-1 flex flex-col items-center"}>
          <SubPageSelector
            currentSubPage={currentSubPage}
            setCurrentSubPage={setCurrentSubPage}
          />
        </ResizablePanel>
        <ResizableHandle withHandle />
        <ResizablePanel
        className={"w-full flex justify-center items-center"}>
          <SubPage currentSubPage={currentSubPage}/>
        </ResizablePanel>
      </ResizablePanelGroup>
    </main>
  );
}

interface SubPageSelectorProps {
  currentSubPage: ESubPage
  setCurrentSubPage: Dispatch<SetStateAction<ESubPage>>
}

function SubPageSelector(props: SubPageSelectorProps) {
  return (
    <div className={"w-full flex flex-col justify-center items-stretch pt-4 p-4 gap-2"}>
      <Button
        onClick={()=>props.setCurrentSubPage(ESubPage.Home)}
        disabled={props.currentSubPage === ESubPage.Home}
        className={"gap-1 font-bold"}>
        <Home/>
        Accueil
      </Button>
      <NewFileModal/>
      <Button
        onClick={()=>props.setCurrentSubPage(ESubPage.Documentation)}
        disabled={props.currentSubPage === ESubPage.Documentation}>
        <NotepadTextDashed />
        Documentation
      </Button>
    </div>
  )
}

export interface ISubPageProps {
  currentSubPage: ESubPage
}

function SubPage(props: ISubPageProps) {
  switch (props.currentSubPage) {
    case ESubPage.Home:
      return (<>Home</>)
    case ESubPage.Documentation:
      return (<>Doc</>)
    default:
      return (<>Default</>)
  }
}
